@@ -1,10 +1,10 @@
-## ----setup, include = FALSE----------------------------------------------
+## ----setup, include = FALSE---------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(texPreview)
 
 tex_opts$set( 
@@ -13,13 +13,13 @@ tex_opts$set(
 )
 
 
-## ----testOut-------------------------------------------------------------
+## ----testOut------------------------------------------------------------------
 
-knitr::kable(head(iris,5),format = 'latex')%>%
+knitr::kable(head(iris,5),format = 'latex') |>
 tex_preview()
 
 
-## ----testOut2------------------------------------------------------------
+## ----testOut2-----------------------------------------------------------------
 tab='
 \\begin{tabular}{llr}
 \\hline
@@ -35,7 +35,7 @@ Armadillo & frozen      & 8.99       \\\\
 \\hline
 \\end{tabular}'
 
-tab%>%
+tab |>
   tex_preview()
 
 
