@@ -5,6 +5,7 @@ path <- file.path(tempdir(),'tex_err')
 cleanup(path)
 
 tex_opts$set(returnType = 'tex',fileDir = path)
+options(tinytex.compile.max_times = 1)
 
 tex <- '\\begin{tabular}{ll}
 3&3&3
@@ -13,9 +14,10 @@ tex <- '\\begin{tabular}{ll}
 testthat::describe('force an error',{
   
   it('error message', {
-    testthat::expect_error(texPreview::tex_preview(tex,marker = FALSE),'Extra alignment tab')
+    testthat::expect_error(texPreview::tex_preview(tex,marker = FALSE),'LaTeX failed to compile')
   })
 
 })
 
+options(tinytex.compile.max_times = NULL)
 cleanup(path,create = FALSE)
